// Variable Section

// Main Section
var script = {
    name: 'CarouselDiagonal',
    props: {
        screens: {},
        sideWidth: { default: function (){ return 5 } },
        color: { default: function (){ return '#AA0F2F' } },
        textPrev: { default: function (){ return 'PREV' } },
        muted: {},
    },
    watch: {
        muted: function (val) {
            this.muted_ = val;
        },
    },
    data: function () {
        return {
            video: null,
            indexHover: null,
            indexClick: null,
            muted_: true,
            widthPointer: 0,
            leftPointer: 0,
        }
    },
    created: function created() {},
    methods: {
        indexScreen: function indexScreen (screen) {
            if(!screen) { return }
            return this.screens.indexOf(screen)
        },
        refScreen: function refScreen (screen) {
            if(!screen) { return }
            return 'screen' + this.indexScreen(screen)
        },
        setHoverIndex: function setHoverIndex (screen) {
            if (this.indexClick==null) {
                this.indexHover = this.indexScreen(screen);
                this.play(screen);
            }
        },
        resetHoverIndex: function resetHoverIndex () {
            if (this.indexClick==null) {
                this.indexHover = null;
            }
        },
        setClickIndex: function setClickIndex (screen) {
            if(screen == this.screen) { return }
            this.indexClick = this.indexScreen(screen);
            this.play(screen);
        },
        setNextClickIndex: function setNextClickIndex (screen) {
            this.indexClick = this.indexScreen(screen);
            this.indexClick = (this.indexClick+1) % this.countScreen;
        },
        resetClickIndex: function resetClickIndex () {
            this.indexClick = null;
        },
        leftTitle: function leftTitle (screen) {
            var index = this.indexScreen(screen);

            // Check index
            if (index === 0) {
                return this.widthScreen/4 + this.sideWidth/2
            } else if (index === this.screens.length-1) {
                return 100 - this.widthScreen/4 - this.sideWidth/2
            } else {
                return index * this.widthScreen + this.sideWidth
            }
        },
        zIndexScreen: function zIndexScreen (screen) {
            return this.indexScreen(screen) + 1
        },
        clipPathScreen: function clipPathScreen (screen) {
            var result;
            var index = this.indexScreen(screen);
            if (index === 0) {
                return 'polygon(0% 0, 100% 0, 100% 100%, 0% 100%)'
            }
            var top = ((index-1) * this.widthScreen + this.sideWidth);
            var bottom = (index * this.widthScreen + this.sideWidth);

            if (this.indexClick !== null && this.indexClick >= 0) {
                if (index === this.indexClick) {
                    top = 0;
                    bottom = 0;
                } else if (index > this.indexClick) {
                    top = 100;
                    bottom = 100;
                } else {
                    top = 0;
                    bottom = 0;
                }
            }
            if (this.indexClick == null && this.indexHover !== null && this.indexHover >= 0) {
                if (index === this.indexHover) {
                    top -= this.sideWidth;
                    bottom -= this.sideWidth;
                } else if (index === this.indexHover+1) {
                    top += this.sideWidth;
                    bottom += this.sideWidth;
                }
            }
            // eslint-disable-next-line prefer-const
            result = 'polygon(' + top + '% 0, 100% 0, 100% 100%, ' + bottom +'% 100%)';
            return result
        },
        openLink: function openLink (screen) {
            if (screen.link) {
                window.open(screen.link, '_blank');
            }
        },
        getVideo: function getVideo (screen) {
            return this.$refs[this.refScreen(screen)][0]
        },
        stop: function stop (screen) {
            this.video = this.getVideo(screen);
            this.video.currentTime = 0;
            this.video.pause();
        },
        stopAll: function stopAll (screen) {
            for (var i=0; i<this.screens.length; i++) {
                if (screen!=this.screens[i]){
                    this.stop(this.screens[i]);
                }
            }
        },
        play: function play (screen) {
            this.stopAll(screen);
            this.video = this.getVideo(screen);
            this.video.play();
        },
        timeupdate: function timeupdate ($event) {
            var video = $event.target;
            this.widthPointer = this.widthPagination * (video ? video.currentTime / video.duration : 0);
            this.leftPointer = this.widthPagination * this.indexClick;
        },
        ended: function ended (screen) {
            this.setNextClickIndex(screen);
            this.play(this.screen);
        },
        toggleMute: function toggleMute () {
            this.muted_ = !this.muted_;
        }
    },
    computed: {
        countScreen: function countScreen () {
            return this.screens.length
        },
        widthScreen: function widthScreen () {
            var sideWidth = 5;
            if( this.sideWidth>0 && this.sideWidth<100 ) {
                sideWidth = this.sideWidth;
            }
            return (100 - sideWidth*2) / (this.screens.length-1)
        },
        screen: function screen () {
            if(this.indexClick!=null) {
                return this.screens[this.indexClick]
            } else {
                return null
            }
        },
        widthPagination: function widthPagination () {
            return (100 / this.countScreen)
        },
        clipPathPaginations: function clipPathPaginations () {
            var result = 'polygon(';
            for (var i=0; i<this.countScreen; i++) {
                var left = (void 0), right = (void 0);

                // Set Left
                if (i==0) { left = 0; }
                else { result += ' '; left = this.widthPagination*i+1; }
                result += left+'% 0%, '+left+'% 100%,';

                // Set Right
                if (i == this.countScreen-1) { right = 100; }
                else { right = this.widthPagination*(i+1)-1; }
                result += ' ' + right+'% 100%, '+right+'% 0%';

                if (i != this.countScreen-1) { result += ','; }
            }
            return result + ')'
        },
        isPartialSound: function isPartialSound () {
            var result = false;
            for (var i=0; i<this.countScreen; i++){
                var screen = this.screens[i];
                if(screen.isSound) {
                    result = true;
                }
            }
            return result
        }
    }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    var options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    var hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            var originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            var existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

var isOldIE = typeof navigator !== 'undefined' &&
    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
    return function (id, style) { return addStyle(id, style); };
}
var HEAD;
var styles = {};
function addStyle(id, css) {
    var group = isOldIE ? css.media || 'default' : id;
    var style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
    if (!style.ids.has(id)) {
        style.ids.add(id);
        var code = css.source;
        if (css.map) {
            // https://developer.chrome.com/devtools/docs/javascript-debugging
            // this makes source maps inside style tags work properly in Chrome
            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
            // http://stackoverflow.com/a/26603875
            code +=
                '\n/*# sourceMappingURL=data:application/json;base64,' +
                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                    ' */';
        }
        if (!style.element) {
            style.element = document.createElement('style');
            style.element.type = 'text/css';
            if (css.media)
                { style.element.setAttribute('media', css.media); }
            if (HEAD === undefined) {
                HEAD = document.head || document.getElementsByTagName('head')[0];
            }
            HEAD.appendChild(style.element);
        }
        if ('styleSheet' in style.element) {
            style.styles.push(code);
            style.element.styleSheet.cssText = style.styles
                .filter(Boolean)
                .join('\n');
        }
        else {
            var index = style.ids.size - 1;
            var textNode = document.createTextNode(code);
            var nodes = style.element.childNodes;
            if (nodes[index])
                { style.element.removeChild(nodes[index]); }
            if (nodes.length)
                { style.element.insertBefore(textNode, nodes[index]); }
            else
                { style.element.appendChild(textNode); }
        }
    }
}

/* script */
var __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    {
      class: { clicked: _vm.indexClick !== null },
      attrs: { id: "CarouselDiagonal" },
      on: { mouseleave: _vm.resetHoverIndex }
    },
    [
      _vm._l(_vm.screens, function(screen, index) {
        return _c(
          "div",
          {
            key: index,
            staticClass: "screen",
            style: {
              "clip-path": _vm.clipPathScreen(screen),
              "z-index": _vm.zIndexScreen(screen)
            },
            on: {
              mouseover: function($event) {
                return _vm.setHoverIndex(screen)
              },
              click: function($event) {
                return _vm.setClickIndex(screen)
              }
            }
          },
          [
            screen.video
              ? _c(
                  "video",
                  {
                    ref: _vm.refScreen(screen),
                    refInFor: true,
                    staticClass: "b-img",
                    attrs: { playsinline: "", "webkit-playsinline": "" },
                    domProps: { muted: _vm.muted_ },
                    on: {
                      timeupdate: _vm.timeupdate,
                      ended: function($event) {
                        return _vm.ended(screen)
                      }
                    }
                  },
                  [
                    _c("source", {
                      attrs: { src: screen.video, type: "video/mp4" }
                    })
                  ]
                )
              : _vm._e(),
            _vm._v(" "),
            screen.image
              ? _c("img", {
                  ref: _vm.refScreen(screen),
                  refInFor: true,
                  staticClass: "b-img",
                  attrs: { src: screen.image }
                })
              : _vm._e(),
            _vm._v(" "),
            _c(
              "div",
              {
                staticClass: "title",
                style: {
                  left: _vm.leftTitle(screen) + "%"
                }
              },
              [
                _c("div", { staticClass: "title1" }, [
                  _vm._v(_vm._s(screen.subtitle))
                ]),
                _c("br"),
                _vm._v(" "),
                _c("div", { staticClass: "title2" }, [
                  _vm._v(_vm._s(screen.title))
                ])
              ]
            )
          ]
        )
      }),
      _vm._v(" "),
      _vm.screen
        ? _c("div", { staticClass: "bottom" }, [
            _c("div", { staticClass: "info" }, [
              _c("div", { staticClass: "page" }, [
                _c("span", [_vm._v(_vm._s(_vm.indexClick + 1))]),
                _vm._v(" "),
                _c("span", [_vm._v("/ " + _vm._s(_vm.screens.length))])
              ]),
              _vm._v(" "),
              _c(
                "button",
                {
                  staticClass: "title",
                  on: {
                    click: function($event) {
                      return _vm.openLink(_vm.screen)
                    }
                  }
                },
                [
                  _vm._v(
                    "\n                " +
                      _vm._s(_vm.screen.subtitle) +
                      "\n                "
                  ),
                  _c("b", [_vm._v(_vm._s(_vm.screen.title))]),
                  _vm._v(" "),
                  _c(
                    "svg",
                    {
                      attrs: {
                        width: "11px",
                        height: "20px",
                        viewBox: "0 0 11 20",
                        version: "1.1",
                        xmlns: "http://www.w3.org/2000/svg"
                      }
                    },
                    [
                      _c(
                        "g",
                        {
                          attrs: {
                            id: "Icons",
                            stroke: "none",
                            "stroke-width": "1",
                            fill: "none",
                            "fill-rule": "evenodd"
                          }
                        },
                        [
                          _c(
                            "g",
                            {
                              attrs: {
                                id: "Rounded",
                                transform:
                                  "translate(-345.000000, -3434.000000)"
                              }
                            },
                            [
                              _c(
                                "g",
                                {
                                  attrs: {
                                    id: "Navigation",
                                    transform:
                                      "translate(100.000000, 3378.000000)"
                                  }
                                },
                                [
                                  _c(
                                    "g",
                                    {
                                      attrs: {
                                        id:
                                          "-Round-/-Navigation-/-arrow_forward_ios",
                                        transform:
                                          "translate(238.000000, 54.000000)"
                                      }
                                    },
                                    [
                                      _c("g", [
                                        _c("polygon", {
                                          attrs: {
                                            id: "Path",
                                            opacity: "0.87",
                                            points: "24 24 0 24 0 0 24 0"
                                          }
                                        }),
                                        _vm._v(" "),
                                        _c("path", {
                                          attrs: {
                                            d:
                                              "M7.38,21.01 C7.87,21.5 8.66,21.5 9.15,21.01 L17.46,12.7 C17.85,12.31 17.85,11.68 17.46,11.29 L9.15,2.98 C8.66,2.49 7.87,2.49 7.38,2.98 C6.89,3.47 6.89,4.26 7.38,4.75 L14.62,12 L7.37,19.25 C6.89,19.73 6.89,20.53 7.38,21.01 Z",
                                            id: "🔹-Icon-Color",
                                            fill: "#FFFFFF"
                                          }
                                        })
                                      ])
                                    ]
                                  )
                                ]
                              )
                            ]
                          )
                        ]
                      )
                    ]
                  )
                ]
              )
            ]),
            _vm._v(" "),
            _c(
              "div",
              { staticClass: "buttons" },
              _vm._l(_vm.screens, function(screen, index) {
                return _c("button", {
                  key: index,
                  style: { width: _vm.widthPagination + "%" },
                  on: {
                    click: function($event) {
                      return _vm.setClickIndex(_vm.screens[index])
                    }
                  }
                })
              }),
              0
            ),
            _vm._v(" "),
            _c(
              "div",
              {
                staticClass: "paginations",
                style: { "clip-path": _vm.clipPathPaginations }
              },
              [
                _vm._l(_vm.screens, function(screen, index) {
                  return _c("button", {
                    key: index,
                    staticClass: "pagination",
                    style: { width: _vm.widthPagination + "%" },
                    on: {
                      click: function($event) {
                        return _vm.setClickIndex(_vm.screens[index])
                      }
                    }
                  })
                }),
                _vm._v(" "),
                _c("div", {
                  staticClass: "pointer",
                  staticStyle: { "pointer-events": "none" },
                  style: {
                    width: _vm.widthPointer + "%",
                    left: _vm.leftPointer + "%",
                    background: _vm.color
                  }
                })
              ],
              2
            ),
            _vm._v(" "),
            _c(
              "div",
              { staticClass: "buttons" },
              _vm._l(_vm.screens, function(screen, index) {
                return _c("button", {
                  key: index,
                  style: { width: _vm.widthPagination + "%" },
                  on: {
                    click: function($event) {
                      return _vm.setClickIndex(_vm.screens[index])
                    }
                  }
                })
              }),
              0
            )
          ])
        : _vm._e(),
      _vm._v(" "),
      _c(
        "transition",
        { attrs: { name: "fade" } },
        [
          _vm._t("reset", [
            _vm.indexClick !== null
              ? _c(
                  "button",
                  { staticClass: "reset", on: { click: _vm.resetClickIndex } },
                  [
                    _c(
                      "svg",
                      {
                        attrs: {
                          width: "11px",
                          height: "20px",
                          viewBox: "0 0 11 20",
                          version: "1.1",
                          xmlns: "http://www.w3.org/2000/svg",
                          "xmlns:xlink": "http://www.w3.org/1999/xlink"
                        }
                      },
                      [
                        _c(
                          "g",
                          {
                            attrs: {
                              id: "Icons",
                              stroke: "none",
                              "stroke-width": "1",
                              fill: "none",
                              "fill-rule": "evenodd"
                            }
                          },
                          [
                            _c(
                              "g",
                              {
                                attrs: {
                                  id: "Rounded",
                                  transform:
                                    "translate(-548.000000, -3434.000000)"
                                }
                              },
                              [
                                _c(
                                  "g",
                                  {
                                    attrs: {
                                      id: "Navigation",
                                      transform:
                                        "translate(100.000000, 3378.000000)"
                                    }
                                  },
                                  [
                                    _c(
                                      "g",
                                      {
                                        attrs: {
                                          id:
                                            "-Round-/-Navigation-/-arrow_back_ios",
                                          transform:
                                            "translate(442.000000, 54.000000)"
                                        }
                                      },
                                      [
                                        _c("g", [
                                          _c("polygon", {
                                            attrs: {
                                              id: "Path",
                                              opacity: "0.87",
                                              points: "0 0 24 0 24 24 0 24"
                                            }
                                          }),
                                          _vm._v(" "),
                                          _c("path", {
                                            attrs: {
                                              d:
                                                "M16.62,2.99 C16.13,2.5 15.34,2.5 14.85,2.99 L6.54,11.3 C6.15,11.69 6.15,12.32 6.54,12.71 L14.85,21.02 C15.34,21.51 16.13,21.51 16.62,21.02 C17.11,20.53 17.11,19.74 16.62,19.25 L9.38,12 L16.63,4.75 C17.11,4.27 17.11,3.47 16.62,2.99 Z",
                                              id: "🔹-Icon-Color",
                                              fill: "#FFFFFF"
                                            }
                                          })
                                        ])
                                      ]
                                    )
                                  ]
                                )
                              ]
                            )
                          ]
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c("span", [_vm._v(_vm._s(_vm.textPrev))])
                  ]
                )
              : _vm._e()
          ])
        ],
        2
      ),
      _vm._v(" "),
      _vm.screen && _vm.screen.link
        ? _c("button", {
            staticClass: "link-button",
            on: {
              click: function($event) {
                return _vm.openLink(_vm.screen)
              }
            }
          })
        : _vm._e(),
      _vm._v(" "),
      !_vm.isPartialSound || (_vm.screen && _vm.screen.isSound)
        ? _vm._t("mute", [
            _c(
              "button",
              {
                staticClass: "mute",
                staticStyle: {
                  width: "40px",
                  height: "60px",
                  position: "absolute",
                  top: "10%",
                  right: "5%",
                  transition: "all 500ms",
                  opacity: "0.5",
                  "z-index": "99"
                },
                attrs: {
                  onmouseover: "style.opacity=1",
                  onmouseleave: "style.opacity=0.5"
                },
                on: { click: _vm.toggleMute }
              },
              [
                _vm.muted_
                  ? _c(
                      "svg",
                      {
                        attrs: {
                          width: "24",
                          height: "19",
                          viewBox: "0 0 24 19",
                          fill: "none",
                          xmlns: "http://www.w3.org/2000/svg"
                        }
                      },
                      [
                        _c("path", {
                          attrs: {
                            "fill-rule": "evenodd",
                            "clip-rule": "evenodd",
                            d:
                              "M11.8331 0.0986395C12.1795 0.265097 12.3999 0.615389 12.4 0.999749L12.404 17.1837C12.4041 17.5682 12.1838 17.9187 11.8373 18.0852C11.4908 18.2518 11.0795 18.205 10.7793 17.9649L5.27322 13.56H1C0.447715 13.56 0 13.1123 0 12.56V5.624C0 5.07171 0.447715 4.624 1 4.624H5.26922L10.7753 0.219127C11.0754 -0.0209806 11.4866 -0.0678183 11.8331 0.0986395ZM10.4005 3.08021L6.24469 6.40487C6.06738 6.54672 5.84707 6.624 5.62 6.624H2V11.56H5.624C5.85107 11.56 6.07138 11.6373 6.2487 11.7791L10.4035 15.103L10.4005 3.08021ZM23.6701 4.91689C24.0606 5.30741 24.0606 5.94058 23.6701 6.3311L20.9092 9.092L23.6701 11.8529C24.0606 12.2434 24.0606 12.8766 23.6701 13.2671C23.2796 13.6576 22.6464 13.6576 22.2559 13.2671L19.495 10.5062L16.7341 13.2671C16.3436 13.6576 15.7104 13.6576 15.3199 13.2671C14.9293 12.8766 14.9293 12.2434 15.3199 11.8529L18.0808 9.092L15.3199 6.3311C14.9293 5.94058 14.9293 5.30741 15.3199 4.91689C15.7104 4.52636 16.3436 4.52636 16.7341 4.91689L19.495 7.67778L22.2559 4.91689C22.6464 4.52636 23.2796 4.52636 23.6701 4.91689Z",
                            fill: "white"
                          }
                        })
                      ]
                    )
                  : _c(
                      "svg",
                      {
                        attrs: {
                          width: "26",
                          height: "19",
                          viewBox: "0 0 26 19",
                          fill: "none",
                          xmlns: "http://www.w3.org/2000/svg"
                        }
                      },
                      [
                        _c("path", {
                          attrs: {
                            "fill-rule": "evenodd",
                            "clip-rule": "evenodd",
                            d:
                              "M22.2545 0.301387C21.8687 -0.0937738 21.2356 -0.101336 20.8404 0.284496C20.4453 0.670328 20.4377 1.30345 20.8235 1.69861C22.8603 3.78464 24.0005 6.58452 24.0005 9.5C24.0005 12.4155 22.8603 15.2154 20.8235 17.3014C20.4377 17.6965 20.4453 18.3297 20.8404 18.7155C21.2356 19.1013 21.8687 19.0938 22.2545 18.6986C24.6561 16.239 26.0005 12.9376 26.0005 9.5C26.0005 6.06236 24.6561 2.76103 22.2545 0.301387ZM18.0816 4.54544C17.6958 4.15025 17.0627 4.14264 16.6675 4.52844C16.2723 4.91424 16.2647 5.54736 16.6505 5.94255C17.5776 6.89223 18.0966 8.16681 18.0966 9.494C18.0966 10.8212 17.5776 12.0958 16.6505 13.0454C16.2647 13.4406 16.2723 14.0738 16.6675 14.4596C17.0627 14.8454 17.6958 14.8377 18.0816 14.4426C19.3734 13.1193 20.0966 11.3433 20.0966 9.494C20.0966 7.6447 19.3734 5.86872 18.0816 4.54544ZM12.64 1.083C12.64 0.697093 12.4179 0.345625 12.0694 0.179903C11.7209 0.0141805 11.3082 0.0637829 11.0088 0.307356L5.37354 4.893H1C0.447715 4.893 0 5.34072 0 5.893V13.108C0 13.6603 0.447715 14.108 1 14.108H5.37354L11.0088 18.6936C11.3082 18.9372 11.7209 18.9868 12.0694 18.8211C12.4179 18.6554 12.64 18.3039 12.64 17.918V1.083ZM6.36017 6.66865L10.64 3.18599V15.815L6.36017 12.3324C6.18183 12.1872 5.95893 12.108 5.729 12.108H2V6.893H5.729C5.95893 6.893 6.18183 6.81377 6.36017 6.66865Z",
                            fill: "white"
                          }
                        })
                      ]
                    )
              ]
            )
          ])
        : _vm._e()
    ],
    2
  )
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  var __vue_inject_styles__ = function (inject) {
    if (!inject) { return }
    inject("data-v-71d14270_0", { source: "#CarouselDiagonal {\n  position: relative;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n}\n#CarouselDiagonal .screen {\n  position: absolute;\n  top: 0;\n  left: 0;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  transition: all 1.2s ease;\n  background: #333333;\n}\n#CarouselDiagonal .screen .title {\n  position: absolute;\n  top: 50%;\n  z-index: 6;\n  display: inline-block;\n  color: white;\n  transition: all 2s;\n  transform: translateX(-50%) translateY(-50%);\n}\n#CarouselDiagonal .screen .title .title1 {\n  font-size: 40px;\n  line-height: 49px;\n  font-weight: 600;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);\n  float: left;\n}\n#CarouselDiagonal .screen .title .title2 {\n  font-size: 50px;\n  line-height: 61px;\n  font-weight: 600;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);\n  float: left;\n}\n#CarouselDiagonal.clicked .title {\n  top: 50% !important;\n  left: 50% !important;\n  opacity: 0;\n  transform: translateX(-50%) translateY(-50%) !important;\n}\n#CarouselDiagonal .bottom {\n  position: absolute;\n  box-sizing: border-box;\n  bottom: 6%;\n  width: 100%;\n  padding-left: 5%;\n  padding-right: 5%;\n  float: left;\n}\n#CarouselDiagonal .bottom .info {\n  position: relative;\n  width: 100%;\n  height: 24px;\n}\n#CarouselDiagonal .bottom .info .page {\n  float: left;\n  display: inline-block;\n  color: white;\n  font-weight: 700;\n  letter-spacing: -0.5px;\n}\n#CarouselDiagonal .bottom .info .page span {\n  opacity: 0.5;\n}\n#CarouselDiagonal .bottom .info .page span:first-child {\n  font-size: larger;\n  font-weight: 900;\n  opacity: 1;\n}\n#CarouselDiagonal .bottom .info .title {\n  float: right;\n  display: inline-block;\n  color: white;\n  font-weight: 800;\n  font-size: 18px;\n  line-height: 22px;\n}\n#CarouselDiagonal .bottom .info .title b {\n  font-weight: 900;\n}\n#CarouselDiagonal .bottom .info .title svg {\n  float: right;\n  margin-left: 9px;\n  height: 22px;\n}\n#CarouselDiagonal .bottom .buttons {\n  width: 100%;\n  height: 10px;\n  clear: both;\n}\n#CarouselDiagonal .bottom .buttons button {\n  height: 100%;\n}\n#CarouselDiagonal .bottom .paginations {\n  position: relative;\n  width: 100%;\n  height: 4px;\n  clear: both;\n  z-index: 99;\n}\n#CarouselDiagonal .bottom .paginations .pagination {\n  height: 100%;\n  background: white;\n  opacity: 0.3;\n  border: none;\n  float: left;\n  z-index: 1;\n}\n#CarouselDiagonal .bottom .paginations .pointer {\n  position: absolute;\n  height: 100%;\n  top: 0;\n  z-index: 2;\n  /*transition: all 250ms linear;*/\n}\n#CarouselDiagonal .reset {\n  position: absolute;\n  top: 50%;\n  left: 2%;\n  z-index: 6;\n  font-size: 14px;\n  color: white;\n  background: none;\n  line-height: 20px;\n  padding: 10px;\n  font-weight: 700;\n}\n#CarouselDiagonal .reset * {\n  float: left;\n}\n#CarouselDiagonal .reset span {\n  line-height: 20px;\n  vertical-align: middle;\n  margin-left: 12px;\n}\n#CarouselDiagonal button.mute svg {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n}\n#CarouselDiagonal .fade-enter-active, #CarouselDiagonal .fade-leave-active {\n  transition: opacity 1s;\n  opacity: 100;\n}\n#CarouselDiagonal .fade-enter, #CarouselDiagonal .fade-leave-to {\n  opacity: 0;\n}\n#CarouselDiagonal .b-img {\n  width: 100%;\n  height: 100%;\n  background-size: cover;\n  background-position: center center;\n  object-fit: cover;\n}\n#CarouselDiagonal button, #CarouselDiagonal button:focus {\n  border: none;\n  outline: none;\n  background: none;\n  cursor: pointer;\n}\n#CarouselDiagonal .link-button {\n  position: absolute;\n  width: 50%;\n  height: 50%;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  background: none;\n  z-index: 99;\n}\n#CarouselDiagonal video::-webkit-media-controls-panel {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-play-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-start-playback-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n\n/*# sourceMappingURL=CarouselDiagonal.vue.map */", map: {"version":3,"sources":["/Users/idist/Desktop/git/library/vue-carousel-diagonal/src/components/CarouselDiagonal.vue","CarouselDiagonal.vue"],"names":[],"mappings":"AA4RA;EACA,kBAAA;EACA,cAAA;EACA,WAAA;EACA,WAAA;EACA,YAAA;AC3RA;AD4RA;EACA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,cAAA;EACA,WAAA;EACA,WAAA;EACA,YAAA;EACA,gBAAA;EACA,yBAAA;EACA,mBAAA;AC1RA;AD2RA;EACA,kBAAA;EACA,QAAA;EACA,UAAA;EACA,qBAAA;EACA,YAAA;EACA,kBAAA;EACA,4CAAA;ACzRA;AD0RA;EACA,eAAA;EACA,iBAAA;EACA,gBAAA;EACA,yCAAA;EACA,WAAA;ACxRA;AD0RA;EACA,eAAA;EACA,iBAAA;EACA,gBAAA;EACA,yCAAA;EACA,WAAA;ACxRA;AD6RA;EACA,mBAAA;EACA,oBAAA;EACA,UAAA;EACA,uDAAA;AC3RA;AD+RA;EACA,kBAAA;EACA,sBAAA;EACA,UAAA;EACA,WAAA;EACA,gBAAA;EACA,iBAAA;EACA,WAAA;AC7RA;AD8RA;EACA,kBAAA;EACA,WAAA;EACA,YAAA;AC5RA;AD6RA;EACA,WAAA;EACA,qBAAA;EACA,YAAA;EACA,gBAAA;EACA,sBAAA;AC3RA;AD4RA;EACA,YAAA;AC1RA;AD2RA;EACA,iBAAA;EACA,gBAAA;EACA,UAAA;ACzRA;AD6RA;EACA,YAAA;EACA,qBAAA;EACA,YAAA;EACA,gBAAA;EACA,eAAA;EACA,iBAAA;AC3RA;AD4RA;EACA,gBAAA;AC1RA;AD4RA;EACA,YAAA;EACA,gBAAA;EACA,YAAA;AC1RA;AD8RA;EACA,WAAA;EACA,YAAA;EACA,WAAA;AC5RA;AD6RA;EAAA,YAAA;AC1RA;AD4RA;EACA,kBAAA;EACA,WAAA;EACA,WAAA;EACA,WAAA;EACA,WAAA;AC1RA;AD2RA;EACA,YAAA;EACA,iBAAA;EACA,YAAA;EACA,YAAA;EACA,WAAA;EACA,UAAA;ACzRA;AD2RA;EACA,kBAAA;EACA,YAAA;EACA,MAAA;EACA,UAAA;EACA,gCAAA;ACzRA;AD8RA;EACA,kBAAA;EACA,QAAA;EACA,QAAA;EACA,UAAA;EACA,eAAA;EACA,YAAA;EACA,gBAAA;EACA,iBAAA;EACA,aAAA;EACA,gBAAA;AC5RA;AD6RA;EAAA,WAAA;AC1RA;AD2RA;EACA,iBAAA;EACA,sBAAA;EACA,iBAAA;ACzRA;AD8RA;EACA,kBAAA;EACA,QAAA;EACA,SAAA;EACA,gCAAA;AC5RA;ADgSA;EACA,sBAAA;EACA,YAAA;AC9RA;ADgSA;EACA,UAAA;AC9RA;ADgSA;EACA,WAAA;EACA,YAAA;EACA,sBAAA;EACA,kCAAA;EACA,iBAAA;AC9RA;ADgSA;EACA,YAAA;EACA,aAAA;EACA,gBAAA;EACA,eAAA;AC9RA;ADiSA;EACA,kBAAA;EACA,UAAA;EACA,WAAA;EACA,QAAA;EACA,SAAA;EACA,gCAAA;EACA,gBAAA;EACA,WAAA;AC/RA;ADkSA;EAAA,wBAAA;EAAA,wBAAA;AC9RA;AD+RA;EAAA,wBAAA;EAAA,wBAAA;AC3RA;AD4RA;EAAA,wBAAA;EAAA,wBAAA;ACxRA;;AAEA,+CAA+C","file":"CarouselDiagonal.vue","sourcesContent":["<script>\n    // Variable Section\n\n    // Main Section\n    export default {\n        name: 'CarouselDiagonal',\n        props: {\n            screens: {},\n            sideWidth: { default: ()=> { return 5 } },\n            color: { default: ()=> { return '#AA0F2F' } },\n            textPrev: { default: ()=> { return 'PREV' } },\n            muted: {},\n        },\n        watch: {\n            muted: function (val) {\n                this.muted_ = val\n            },\n        },\n        data: function () {\n            return {\n                video: null,\n                indexHover: null,\n                indexClick: null,\n                muted_: true,\n                widthPointer: 0,\n                leftPointer: 0,\n            }\n        },\n        created() {},\n        methods: {\n            indexScreen (screen) {\n                if(!screen) { return }\n                return this.screens.indexOf(screen)\n            },\n            refScreen (screen) {\n                if(!screen) { return }\n                return 'screen' + this.indexScreen(screen)\n            },\n            setHoverIndex (screen) {\n                if (this.indexClick==null) {\n                    this.indexHover = this.indexScreen(screen)\n                    this.play(screen)\n                }\n            },\n            resetHoverIndex () {\n                if (this.indexClick==null) {\n                    this.indexHover = null\n                }\n            },\n            setClickIndex (screen) {\n                if(screen == this.screen) { return }\n                this.indexClick = this.indexScreen(screen)\n                this.play(screen)\n            },\n            setNextClickIndex (screen) {\n                this.indexClick = this.indexScreen(screen)\n                this.indexClick = (this.indexClick+1) % this.countScreen\n            },\n            resetClickIndex () {\n                this.indexClick = null\n            },\n            leftTitle (screen) {\n                const index = this.indexScreen(screen)\n\n                // Check index\n                if (index === 0) {\n                    return this.widthScreen/4 + this.sideWidth/2\n                } else if (index === this.screens.length-1) {\n                    return 100 - this.widthScreen/4 - this.sideWidth/2\n                } else {\n                    return index * this.widthScreen + this.sideWidth\n                }\n            },\n            zIndexScreen (screen) {\n                return this.indexScreen(screen) + 1\n            },\n            clipPathScreen (screen) {\n                let result\n                const index = this.indexScreen(screen)\n                if (index === 0) {\n                    return 'polygon(0% 0, 100% 0, 100% 100%, 0% 100%)'\n                }\n                let top = ((index-1) * this.widthScreen + this.sideWidth)\n                let bottom = (index * this.widthScreen + this.sideWidth)\n\n                if (this.indexClick !== null && this.indexClick >= 0) {\n                    if (index === this.indexClick) {\n                        top = 0\n                        bottom = 0\n                    } else if (index > this.indexClick) {\n                        top = 100\n                        bottom = 100\n                    } else {\n                        top = 0\n                        bottom = 0\n                    }\n                }\n                if (this.indexClick == null && this.indexHover !== null && this.indexHover >= 0) {\n                    if (index === this.indexHover) {\n                        top -= this.sideWidth\n                        bottom -= this.sideWidth\n                    } else if (index === this.indexHover+1) {\n                        top += this.sideWidth\n                        bottom += this.sideWidth\n                    }\n                }\n                // eslint-disable-next-line prefer-const\n                result = 'polygon(' + top + '% 0, 100% 0, 100% 100%, ' + bottom +'% 100%)'\n                return result\n            },\n            openLink (screen) {\n                if (screen.link) {\n                    window.open(screen.link, '_blank')\n                }\n            },\n            getVideo (screen) {\n                return this.$refs[this.refScreen(screen)][0]\n            },\n            stop (screen) {\n                this.video = this.getVideo(screen)\n                this.video.currentTime = 0\n                this.video.pause()\n            },\n            stopAll (screen) {\n                for (let i=0; i<this.screens.length; i++) {\n                    if (screen!=this.screens[i]){\n                        this.stop(this.screens[i])\n                    }\n                }\n            },\n            play (screen) {\n                this.stopAll(screen)\n                this.video = this.getVideo(screen)\n                this.video.play()\n            },\n            timeupdate ($event) {\n                let video = $event.target\n                this.widthPointer = this.widthPagination * (video ? video.currentTime / video.duration : 0)\n                this.leftPointer = this.widthPagination * this.indexClick\n            },\n            ended (screen) {\n                this.setNextClickIndex(screen)\n                this.play(this.screen)\n            },\n            toggleMute () {\n                this.muted_ = !this.muted_\n            }\n        },\n        computed: {\n            countScreen () {\n                return this.screens.length\n            },\n            widthScreen () {\n                let sideWidth = 5\n                if( this.sideWidth>0 && this.sideWidth<100 ) {\n                    sideWidth = this.sideWidth\n                }\n                return (100 - sideWidth*2) / (this.screens.length-1)\n            },\n            screen () {\n                if(this.indexClick!=null) {\n                    return this.screens[this.indexClick]\n                } else {\n                    return null\n                }\n            },\n            widthPagination () {\n                return (100 / this.countScreen)\n            },\n            clipPathPaginations () {\n                let result = 'polygon('\n                for (let i=0; i<this.countScreen; i++) {\n                    let left, right\n\n                    // Set Left\n                    if (i==0) { left = 0 }\n                    else { result += ' '; left = this.widthPagination*i+1 }\n                    result += left+'% 0%, '+left+'% 100%,'\n\n                    // Set Right\n                    if (i == this.countScreen-1) { right = 100 }\n                    else { right = this.widthPagination*(i+1)-1 }\n                    result += ' ' + right+'% 100%, '+right+'% 0%'\n\n                    if (i != this.countScreen-1) { result += ',' }\n                }\n                return result + ')'\n            },\n            isPartialSound () {\n                let result = false\n                for (let i=0; i<this.countScreen; i++){\n                    let screen = this.screens[i]\n                    if(screen.isSound) {\n                        result = true\n                    }\n                }\n                return result\n            }\n        }\n    }\n</script>\n\n<template>\n    <div id=\"CarouselDiagonal\" :class=\"{ 'clicked': indexClick !== null }\" @mouseleave=\"resetHoverIndex\">\n        <!--Videos-->\n        <div v-for=\"(screen, index) in screens\"\n             :key=\"index\" class=\"screen\"\n             @mouseover=\"setHoverIndex(screen)\"\n             @click=\"setClickIndex(screen)\"\n             :style=\"{\n                'clip-path': clipPathScreen(screen),\n                'z-index': zIndexScreen(screen),\n            }\">\n            <!--Video-->\n            <video class=\"b-img\" v-if=\"screen.video\"\n                   :ref=\"refScreen(screen)\"\n                   @timeupdate=\"timeupdate\"\n                   @ended=\"ended(screen)\"\n                   :muted=\"muted_\"\n                   playsinline webkit-playsinline>\n                <source :src=\"screen.video\" type=\"video/mp4\"></video>\n            <img class=\"b-img\" v-if=\"screen.image\" :ref=\"refScreen(screen)\" :src=\"screen.image\"/>\n\n            <!--Title-->\n            <div class=\"title\" :style=\"{\n              'left': leftTitle(screen) + '%',\n            }\">\n                <div class=\"title1\">{{screen.subtitle}}</div><br/>\n                <div class=\"title2\">{{screen.title}}</div>\n            </div>\n        </div>\n\n        <!--Progress-->\n        <div class=\"bottom\" v-if=\"screen\">\n            <div class=\"info\">\n                <div class=\"page\"><span>{{indexClick+1}}</span> <span>/ {{screens.length}}</span></div>\n                <button class=\"title\" @click=\"openLink(screen)\">\n                    {{screen.subtitle}}\n                    <b>{{screen.title}}</b>\n                    <svg width=\"11px\" height=\"20px\" viewBox=\"0 0 11 20\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\"> <g id=\"Icons\" stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\"> <g id=\"Rounded\" transform=\"translate(-345.000000, -3434.000000)\"> <g id=\"Navigation\" transform=\"translate(100.000000, 3378.000000)\"> <g id=\"-Round-/-Navigation-/-arrow_forward_ios\" transform=\"translate(238.000000, 54.000000)\"> <g> <polygon id=\"Path\" opacity=\"0.87\" points=\"24 24 0 24 0 0 24 0\"></polygon> <path d=\"M7.38,21.01 C7.87,21.5 8.66,21.5 9.15,21.01 L17.46,12.7 C17.85,12.31 17.85,11.68 17.46,11.29 L9.15,2.98 C8.66,2.49 7.87,2.49 7.38,2.98 C6.89,3.47 6.89,4.26 7.38,4.75 L14.62,12 L7.37,19.25 C6.89,19.73 6.89,20.53 7.38,21.01 Z\" id=\"🔹-Icon-Color\" fill=\"#FFFFFF\"></path> </g> </g> </g> </g> </g> </svg>\n                </button>\n            </div>\n            <div class=\"buttons\">\n                <button v-for=\"(screen, index) in screens\" :key=\"index\" @click=\"setClickIndex(screens[index])\" :style=\"{width: widthPagination+'%'}\"></button>\n            </div>\n            <div class=\"paginations\" :style=\"{'clip-path': clipPathPaginations}\">\n                <button v-for=\"(screen, index) in screens\" :key=\"index\" class=\"pagination\" @click=\"setClickIndex(screens[index])\" :style=\"{width: widthPagination+'%'}\"></button>\n                <div class=\"pointer\" :style=\"{ width: widthPointer + '%', left: leftPointer + '%', background: color }\" style=\"pointer-events:none;\"></div>\n            </div>\n            <div class=\"buttons\">\n                <button v-for=\"(screen, index) in screens\" :key=\"index\" @click=\"setClickIndex(screens[index])\" :style=\"{width: widthPagination+'%'}\"></button>\n            </div>\n        </div>\n\n        <!--Reset-->\n        <transition name=\"fade\">\n            <slot name=\"reset\">\n                <button class=\"reset\" @click=\"resetClickIndex\" v-if=\"indexClick !== null\">\n                    <svg width=\"11px\" height=\"20px\" viewBox=\"0 0 11 20\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\"> <g id=\"Icons\" stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\"> <g id=\"Rounded\" transform=\"translate(-548.000000, -3434.000000)\"> <g id=\"Navigation\" transform=\"translate(100.000000, 3378.000000)\"> <g id=\"-Round-/-Navigation-/-arrow_back_ios\" transform=\"translate(442.000000, 54.000000)\"> <g> <polygon id=\"Path\" opacity=\"0.87\" points=\"0 0 24 0 24 24 0 24\"></polygon> <path d=\"M16.62,2.99 C16.13,2.5 15.34,2.5 14.85,2.99 L6.54,11.3 C6.15,11.69 6.15,12.32 6.54,12.71 L14.85,21.02 C15.34,21.51 16.13,21.51 16.62,21.02 C17.11,20.53 17.11,19.74 16.62,19.25 L9.38,12 L16.63,4.75 C17.11,4.27 17.11,3.47 16.62,2.99 Z\" id=\"🔹-Icon-Color\" fill=\"#FFFFFF\"></path> </g> </g> </g> </g> </g> </svg>\n                    <span>{{textPrev}}</span>\n                </button>\n            </slot>\n        </transition>\n\n        <!--Link-->\n        <button v-if=\"screen && screen.link\"\n                @click=\"openLink(screen)\"\n                class=\"link-button\"></button>\n\n        <!--Mute-->\n        <slot name=\"mute\" v-if=\"!isPartialSound || (screen && screen.isSound)\">\n            <button class=\"mute\" @click=\"toggleMute\" style=\"width: 40px; height: 60px; position: absolute; top: 10%; right: 5%; transition: all 500ms; opacity: 0.5; z-index: 99;\" onmouseover=\"style.opacity=1\" onmouseleave=\"style.opacity=0.5\">\n                <svg v-if=\"muted_\" width=\"24\" height=\"19\" viewBox=\"0 0 24 19\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M11.8331 0.0986395C12.1795 0.265097 12.3999 0.615389 12.4 0.999749L12.404 17.1837C12.4041 17.5682 12.1838 17.9187 11.8373 18.0852C11.4908 18.2518 11.0795 18.205 10.7793 17.9649L5.27322 13.56H1C0.447715 13.56 0 13.1123 0 12.56V5.624C0 5.07171 0.447715 4.624 1 4.624H5.26922L10.7753 0.219127C11.0754 -0.0209806 11.4866 -0.0678183 11.8331 0.0986395ZM10.4005 3.08021L6.24469 6.40487C6.06738 6.54672 5.84707 6.624 5.62 6.624H2V11.56H5.624C5.85107 11.56 6.07138 11.6373 6.2487 11.7791L10.4035 15.103L10.4005 3.08021ZM23.6701 4.91689C24.0606 5.30741 24.0606 5.94058 23.6701 6.3311L20.9092 9.092L23.6701 11.8529C24.0606 12.2434 24.0606 12.8766 23.6701 13.2671C23.2796 13.6576 22.6464 13.6576 22.2559 13.2671L19.495 10.5062L16.7341 13.2671C16.3436 13.6576 15.7104 13.6576 15.3199 13.2671C14.9293 12.8766 14.9293 12.2434 15.3199 11.8529L18.0808 9.092L15.3199 6.3311C14.9293 5.94058 14.9293 5.30741 15.3199 4.91689C15.7104 4.52636 16.3436 4.52636 16.7341 4.91689L19.495 7.67778L22.2559 4.91689C22.6464 4.52636 23.2796 4.52636 23.6701 4.91689Z\" fill=\"white\"/>\n                </svg>\n                <svg v-else width=\"26\" height=\"19\" viewBox=\"0 0 26 19\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M22.2545 0.301387C21.8687 -0.0937738 21.2356 -0.101336 20.8404 0.284496C20.4453 0.670328 20.4377 1.30345 20.8235 1.69861C22.8603 3.78464 24.0005 6.58452 24.0005 9.5C24.0005 12.4155 22.8603 15.2154 20.8235 17.3014C20.4377 17.6965 20.4453 18.3297 20.8404 18.7155C21.2356 19.1013 21.8687 19.0938 22.2545 18.6986C24.6561 16.239 26.0005 12.9376 26.0005 9.5C26.0005 6.06236 24.6561 2.76103 22.2545 0.301387ZM18.0816 4.54544C17.6958 4.15025 17.0627 4.14264 16.6675 4.52844C16.2723 4.91424 16.2647 5.54736 16.6505 5.94255C17.5776 6.89223 18.0966 8.16681 18.0966 9.494C18.0966 10.8212 17.5776 12.0958 16.6505 13.0454C16.2647 13.4406 16.2723 14.0738 16.6675 14.4596C17.0627 14.8454 17.6958 14.8377 18.0816 14.4426C19.3734 13.1193 20.0966 11.3433 20.0966 9.494C20.0966 7.6447 19.3734 5.86872 18.0816 4.54544ZM12.64 1.083C12.64 0.697093 12.4179 0.345625 12.0694 0.179903C11.7209 0.0141805 11.3082 0.0637829 11.0088 0.307356L5.37354 4.893H1C0.447715 4.893 0 5.34072 0 5.893V13.108C0 13.6603 0.447715 14.108 1 14.108H5.37354L11.0088 18.6936C11.3082 18.9372 11.7209 18.9868 12.0694 18.8211C12.4179 18.6554 12.64 18.3039 12.64 17.918V1.083ZM6.36017 6.66865L10.64 3.18599V15.815L6.36017 12.3324C6.18183 12.1872 5.95893 12.108 5.729 12.108H2V6.893H5.729C5.95893 6.893 6.18183 6.81377 6.36017 6.66865Z\" fill=\"white\"/>\n                </svg>\n            </button>\n        </slot>\n    </div>\n</template>\n\n<style lang=\"scss\">\n    #CarouselDiagonal {\n        position: relative;\n        display: block;\n        float: left;\n        width: 100%;\n        height: 100%;\n        .screen {\n            position: absolute;\n            top: 0;\n            left: 0;\n            display: block;\n            float: left;\n            width: 100%;\n            height: 100%;\n            overflow: hidden;\n            transition: all 1.2s ease;\n            background: #333333;\n            .title {\n                position: absolute;\n                top: 50%;\n                z-index: 6;\n                display: inline-block;\n                color: white;\n                transition: all 2s;\n                transform: translateX(-50%) translateY(-50%);\n                .title1 {\n                    font-size: 40px;\n                    line-height: 49px;\n                    font-weight: 600;\n                    text-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);\n                    float: left;\n                }\n                .title2 {\n                    font-size: 50px;\n                    line-height: 61px;\n                    font-weight: 600;\n                    text-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);\n                    float: left;\n                }\n            }\n        }\n        &.clicked {\n            .title {\n                top:50% !important;\n                left: 50% !important;\n                opacity: 0;\n                transform: translateX(-50%) translateY(-50%) !important;\n            }\n        }\n\n        .bottom {\n            position: absolute;\n            box-sizing: border-box;\n            bottom: 6%;\n            width: 100%;\n            padding-left: 5%;\n            padding-right: 5%;\n            float: left;\n            .info {\n                position: relative;\n                width: 100%;\n                height: 24px;\n                .page {\n                    float: left;\n                    display: inline-block;\n                    color: white;\n                    font-weight: 700;\n                    letter-spacing: -0.5px;\n                    span {\n                        opacity: 0.5;\n                        &:first-child {\n                            font-size: larger;\n                            font-weight: 900;\n                            opacity: 1;\n                        }\n                    }\n                }\n                .title {\n                    float: right;\n                    display: inline-block;\n                    color: white;\n                    font-weight: 800;\n                    font-size: 18px;\n                    line-height: 22px;\n                    b {\n                        font-weight: 900;\n                    }\n                    svg {\n                        float: right;\n                        margin-left: 9px;\n                        height: 22px;\n                    }\n                }\n            }\n            .buttons {\n                width: 100%;\n                height: 10px;\n                clear: both;\n                button { height: 100%; }\n            }\n            .paginations {\n                position: relative;\n                width: 100%;\n                height: 4px;\n                clear: both;\n                z-index: 99;\n                .pagination {\n                    height: 100%;\n                    background: white;\n                    opacity: 0.3;\n                    border: none;\n                    float: left;\n                    z-index: 1;\n                }\n                .pointer {\n                    position: absolute;\n                    height: 100%;\n                    top: 0;\n                    z-index: 2;\n                    /*transition: all 250ms linear;*/\n                }\n            }\n        }\n\n        .reset {\n            position: absolute;\n            top: 50%;\n            left: 2%;\n            z-index: 6;\n            font-size: 14px;\n            color: white;\n            background: none;\n            line-height: 20px;\n            padding: 10px;\n            font-weight: 700;\n            * { float: left; }\n            span {\n                line-height: 20px;\n                vertical-align: middle;\n                margin-left: 12px;\n            }\n        }\n\n        button.mute {\n            svg {\n                position: absolute;\n                top: 50%;\n                left: 50%;\n                transform: translate(-50%, -50%);\n            }\n        }\n\n        .fade-enter-active, .fade-leave-active {\n            transition: opacity 1s;\n            opacity: 100;\n        }\n        .fade-enter, .fade-leave-to /* .fade-leave-active below version 2.1.8 */ {\n            opacity: 0;\n        }\n        .b-img {\n            width: 100%;\n            height: 100%;\n            background-size: cover;\n            background-position: center center;\n            object-fit: cover;\n        }\n        button, button:focus {\n            border:none;\n            outline: none;\n            background: none;\n            cursor: pointer;\n        }\n\n        .link-button {\n            position: absolute;\n            width: 50%;\n            height: 50%;\n            top: 50%;\n            left: 50%;\n            transform: translate(-50%, -50%);\n            background: none;\n            z-index: 99;\n        }\n\n        video::-webkit-media-controls-panel { display: none!important; -webkit-appearance: none; }\n        video::-webkit-media-controls-play-button { display: none!important; -webkit-appearance: none; }\n        video::-webkit-media-controls-start-playback-button { display: none!important; -webkit-appearance: none; }\n    }\n</style>","#CarouselDiagonal {\n  position: relative;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n}\n#CarouselDiagonal .screen {\n  position: absolute;\n  top: 0;\n  left: 0;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  transition: all 1.2s ease;\n  background: #333333;\n}\n#CarouselDiagonal .screen .title {\n  position: absolute;\n  top: 50%;\n  z-index: 6;\n  display: inline-block;\n  color: white;\n  transition: all 2s;\n  transform: translateX(-50%) translateY(-50%);\n}\n#CarouselDiagonal .screen .title .title1 {\n  font-size: 40px;\n  line-height: 49px;\n  font-weight: 600;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);\n  float: left;\n}\n#CarouselDiagonal .screen .title .title2 {\n  font-size: 50px;\n  line-height: 61px;\n  font-weight: 600;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);\n  float: left;\n}\n#CarouselDiagonal.clicked .title {\n  top: 50% !important;\n  left: 50% !important;\n  opacity: 0;\n  transform: translateX(-50%) translateY(-50%) !important;\n}\n#CarouselDiagonal .bottom {\n  position: absolute;\n  box-sizing: border-box;\n  bottom: 6%;\n  width: 100%;\n  padding-left: 5%;\n  padding-right: 5%;\n  float: left;\n}\n#CarouselDiagonal .bottom .info {\n  position: relative;\n  width: 100%;\n  height: 24px;\n}\n#CarouselDiagonal .bottom .info .page {\n  float: left;\n  display: inline-block;\n  color: white;\n  font-weight: 700;\n  letter-spacing: -0.5px;\n}\n#CarouselDiagonal .bottom .info .page span {\n  opacity: 0.5;\n}\n#CarouselDiagonal .bottom .info .page span:first-child {\n  font-size: larger;\n  font-weight: 900;\n  opacity: 1;\n}\n#CarouselDiagonal .bottom .info .title {\n  float: right;\n  display: inline-block;\n  color: white;\n  font-weight: 800;\n  font-size: 18px;\n  line-height: 22px;\n}\n#CarouselDiagonal .bottom .info .title b {\n  font-weight: 900;\n}\n#CarouselDiagonal .bottom .info .title svg {\n  float: right;\n  margin-left: 9px;\n  height: 22px;\n}\n#CarouselDiagonal .bottom .buttons {\n  width: 100%;\n  height: 10px;\n  clear: both;\n}\n#CarouselDiagonal .bottom .buttons button {\n  height: 100%;\n}\n#CarouselDiagonal .bottom .paginations {\n  position: relative;\n  width: 100%;\n  height: 4px;\n  clear: both;\n  z-index: 99;\n}\n#CarouselDiagonal .bottom .paginations .pagination {\n  height: 100%;\n  background: white;\n  opacity: 0.3;\n  border: none;\n  float: left;\n  z-index: 1;\n}\n#CarouselDiagonal .bottom .paginations .pointer {\n  position: absolute;\n  height: 100%;\n  top: 0;\n  z-index: 2;\n  /*transition: all 250ms linear;*/\n}\n#CarouselDiagonal .reset {\n  position: absolute;\n  top: 50%;\n  left: 2%;\n  z-index: 6;\n  font-size: 14px;\n  color: white;\n  background: none;\n  line-height: 20px;\n  padding: 10px;\n  font-weight: 700;\n}\n#CarouselDiagonal .reset * {\n  float: left;\n}\n#CarouselDiagonal .reset span {\n  line-height: 20px;\n  vertical-align: middle;\n  margin-left: 12px;\n}\n#CarouselDiagonal button.mute svg {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n}\n#CarouselDiagonal .fade-enter-active, #CarouselDiagonal .fade-leave-active {\n  transition: opacity 1s;\n  opacity: 100;\n}\n#CarouselDiagonal .fade-enter, #CarouselDiagonal .fade-leave-to {\n  opacity: 0;\n}\n#CarouselDiagonal .b-img {\n  width: 100%;\n  height: 100%;\n  background-size: cover;\n  background-position: center center;\n  object-fit: cover;\n}\n#CarouselDiagonal button, #CarouselDiagonal button:focus {\n  border: none;\n  outline: none;\n  background: none;\n  cursor: pointer;\n}\n#CarouselDiagonal .link-button {\n  position: absolute;\n  width: 50%;\n  height: 50%;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  background: none;\n  z-index: 99;\n}\n#CarouselDiagonal video::-webkit-media-controls-panel {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-play-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-start-playback-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n\n/*# sourceMappingURL=CarouselDiagonal.vue.map */"]}, media: undefined });

  };
  /* scoped */
  var __vue_scope_id__ = undefined;
  /* module identifier */
  var __vue_module_identifier__ = undefined;
  /* functional template */
  var __vue_is_functional_template__ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  var __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    createInjector,
    undefined,
    undefined
  );

// Import vue component

// Declare install function executed by Vue.use()
function install(Vue) {
    if (install.installed) { return; }
    install.installed = true;
    Vue.component('DiagnoalScreen', __vue_component__);
}

// Create module definition for Vue.use()
var plugin = {
    install: install,
};

// Auto-install when vue is found (eg. in browser via <script> tag)
var GlobalVue = null;
if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
} else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
}
if (GlobalVue) {
    GlobalVue.use(plugin);
}

export default __vue_component__;
export { install };
